# file generated by setuptools_scm
# don't change, don't track in version control
__version__ = version = '1.11.1.dev0+g447bac51.d20230508'
__version_tuple__ = version_tuple = (1, 11, 1, 'dev0', 'g447bac51.d20230508')
